using System;
using System.Collections.Generic;
using System.Reflection;
using Xamarin.Forms;

namespace SampleWebView
{
    public class SamplePage:ContentPage
    {
        internal View Master { get; set; }

        internal bool IsPropertyViewVisible { get; set; }

        private readonly AbsoluteLayout contentLayout;

        private AbsoluteLayout propertyLayout;

        private ToolbarItem sampleListToolbarItem;

        private bool isSampleListVisible;

        private ToolbarItem toolbarItem;

        private View sampleList;

        private BoxView touchView;

        const double sampleListWidth = 240; // Width/100*40;

        internal View SampleList
        {
            get { return sampleList; }
            set
            {
                sampleList = value;

                if (contentLayout.Children.Contains(sampleList)) return;
                contentLayout.Children.Add(sampleList);
                sampleList.IsVisible = false;
            }
        }

        public View ContentView
        {
            get { return (View)GetValue(ContentViewProperty); }
            set { SetValue(ContentViewProperty, value); }
        }

        public static readonly BindableProperty ContentViewProperty =
            BindableProperty.Create<SamplePage, View>(p => p.ContentView, null, BindingMode.Default, null,
                OnContentViewChanged);

        private static void OnContentViewChanged(BindableObject bindable, View oldValue, View newValue)
        {
            ((SamplePage)bindable).OnContentViewChanged();
        }

        private void OnContentViewChanged()
        {
            touchView = new BoxView { BackgroundColor = Color.Gray, Opacity = 0.5, IsVisible = false };

            contentLayout.Children.Add(ContentView);
            contentLayout.Children.Add(touchView);

            var tapGestureRecognizer = new TapGestureRecognizer();
            tapGestureRecognizer.Tapped += tapGestureRecognizer_Tapped;
            touchView.GestureRecognizers.Add(tapGestureRecognizer);

            if (Device.OS == TargetPlatform.Android)
                contentLayout.BackgroundColor = Color.White;
            Content = contentLayout;
        }

        private void tapGestureRecognizer_Tapped(object sender, EventArgs e)
        {
            if (!isSampleListVisible) return;
            touchView.IsVisible = false;
            HideSampleList();
        }


        public void HideSampleList()
        {
            if (sampleList == null) return;
            touchView.IsVisible = false;
            sampleList.IsVisible = false;
            isSampleListVisible = false;
        }

      
        public SamplePage()
        {
            contentLayout = new AbsoluteLayout();
            Command<Type> navigateCommand =
               new Command<Type>(async (Type pageType) =>
               {
                   // Get all the constructors of the page type.
                   IEnumerable<ConstructorInfo> constructors =
                           pageType.GetTypeInfo().DeclaredConstructors;

                   foreach (ConstructorInfo constructor in constructors)
                   {
                       // Check if the constructor has no parameters.
                       if (constructor.GetParameters().Length == 0)
                       {
                           // If so, instantiate it, and navigate to it.
                           Page page = (Page)constructor.Invoke(null);
                           await this.Navigation.PushAsync(page);
                           break;
                       }
                   }
               });
            this.Title = "Loading document to web view";
            this.Content = new TableView
            {
                Intent = TableIntent.Menu,
                Root = new TableRoot("Loading document to web view")
                {
                        new TableSection("")
                        {
                            new TextCell
                            {
                                Text = "Generate Document",
                                Command = navigateCommand,
                                CommandParameter = typeof(WordToHtml)
                            },
                        },  
                }
            };
        }



    }
}